package handlers

import (
	"fmt"
	"github.com/gofiber/fiber/v2"
	"lmika.dev/lmika/hugo-cms/services/sites"
	"time"
)

type Site struct {
	Site *sites.Service
}

func (s *Site) Create(c *fiber.Ctx) error {
	user := GetUser(c)

	site, err := s.Site.CreateSite(c.UserContext(), user, "New Site "+time.Now().Format("2006-01-02 15:04:05"))
	if err != nil {
		return err
	}

	return c.Redirect(fmt.Sprintf("/sites/%v/posts", site.ID))
}

func (s *Site) Show(c *fiber.Ctx) error {
	id, err := c.ParamsInt("siteId")
	if err != nil {
		return err
	}

	site, err := s.Site.GetSite(c.UserContext(), id)
	if err != nil {
		return err
	}

	return c.Render("sites/index", fiber.Map{
		"site": site,
	}, "layouts/main")
}

func (s *Site) Rebuild(c *fiber.Ctx) error {
	if err := s.Site.Rebuild(c.UserContext(), GetSite(c)); err != nil {
		return err
	}

	return c.Redirect(fmt.Sprintf("/sites/%v/posts", GetSite(c).ID))
}

func (s *Site) WithSite() fiber.Handler {
	return func(c *fiber.Ctx) error {
		id, err := c.ParamsInt("siteId")
		if err != nil {
			return err
		}

		site, err := s.Site.GetSite(c.UserContext(), id)
		if err != nil {
			return err
		}

		c.Locals("site", site)
		return c.Next()
	}
}
